LayoutException class final
Thrown when a record layout is invalid or used inconsistently.
- Inheritance
-
- Object
- PulseSlabException
- LayoutException
Constructors
- LayoutException(String message)
-
Creates a layout exception.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited